pub enum ErrorKind {
HttpResponse {
status: StatusCode,
error_code: Option<String>,
raw_response: Option<Box<RawResponse>>,
},
Connection,
Io,
DataConversion,
Credential,
Other,
}Available on crate feature
export-azure only.Expand description
The kind of error.
The classification of error is intentionally fairly coarse.
Variants
HttpResponse
Available on crate feature
http only.An HTTP status code that was not expected.
Fields

status: StatusCodeAn HTTP status code.

error_code: Option<String>An error code returned by the service, or a friendly description of the status.

raw_response: Option<Box<RawResponse>>The raw response returned by the service.
Connection
A connection to the server could not be established.
The request was never sent, so it is safe to retry both reads and writes.
Io
An error performing IO.
DataConversion
An error converting data.
Credential
An error getting an API credential token.
Other
A catch all for other kinds of errors.
Implementations