pub struct ErrorDetail {
pub code: Option<String>,
pub message: Option<String>,
pub target: Option<String>,
pub details: Vec<ErrorDetail>,
pub inner_error: Option<InnerError>,
pub additional_properties: HashMap<String, Value>,
}Available on crate feature
export-azure only.Expand description
Details about an error returned from a service.
Implements a standard โErrorDetailsโ as described in the API guidelines.
Fields
code: Option<String>The error code. A machine readable error code defined by the service.
message: Option<String>A human-readable error message describing the error.
target: Option<String>The target of the error (for example, the name of the property in error).
details: Vec<ErrorDetail>Additional details about the error.
inner_error: Option<InnerError>An inner error that may have more specific information about the root cause of the error.
additional_properties: HashMap<String, Value>Additional properties that may be returned with the error.