Method

Enum Method 

#[non_exhaustive]
pub enum Method { Delete, Get, Head, Patch, Post, Put, }
Available on crate feature export-azure only.
Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Delete

The DELETE method requests that the origin server remove the association between the target resource and its current functionality.

See RFC7231, Section 4.3.5.



Get

The GET method requests transfer of a current selected representation for the target resource.

See RFC7231, Section 4.3.1.



Head

The HEAD method is identical to GET except that the server MUST NOT send a message body in the response.

See RFC7231, Section 4.3.2.



Patch

The PATCH method requests that a set of changes described in the request entity be applied to the resource identified by the Request- URI.

See RFC5789, Section 2.



Post

The POST method requests that the target resource process the representation enclosed in the request according to the resourceโ€™s own specific semantics.

For example, POST is used for the following functions (among others):

  • Providing a block of data, such as the fields entered into an HTML form, to a data-handling process;
  • Posting a message to a bulletin board, newsgroup, mailing list, blog, or similar group of articles;
  • Creating a new resource that has yet to be identified by the origin server; and
  • Appending data to a resourceโ€™s existing representation(s).

See RFC7231, Section 4.3.3.



Put

The PUT method requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload.

See RFC7231, Section 4.3.4.

Implementations

Source

impl Method

pub fn is_safe(&self) -> bool

Whether a method is considered โ€œsafeโ€, meaning the request is essentially read-only.

See the spec for more details.

pub const fn as_str(&self) -> &'static str

Returns the HTTP method as a static string slice.