ClientRequestId

Struct ClientRequestId 

pub struct ClientRequestId(/* private fields */);
Available on crate feature export-azure only.
The x-ms-client-request-id header.

Examples

Add a caller-defined client request ID to a request.

use azure_core::{
    http::{ClientMethodOptions, request::options::ClientRequestId},
    Uuid,
};
let client_request_id: String = Uuid::new_v4().into();
let mut options = ClientMethodOptions::default();
options.context.insert(ClientRequestId::new(client_request_id));

Implementations

Source

impl ClientRequestId

pub fn new<S>(s: S) -> ClientRequestId
where S: Into<Cow<'static, str>>,

Creates a new instance of the request option type, which can be used as an HTTP header or query parameter.

This function is typically used to construct a value representing a request option for use in HTTP requests. The specific usage (header or query parameter) depends on how the macro is invoked.

pub const fn from_static(s: &'static str) -> ClientRequestId

Creates a new instance of the request option from a static string slice.