pub struct AsyncResponseBody(/* private fields */);Available on crate feature
export-azure only.Expand description
A response body stream.
This body can either be streamed or collected into Bytes.
Implementations
Sourceimpl AsyncResponseBody
impl AsyncResponseBody
Sourcepub async fn collect_into(self, buffer: &mut [u8]) -> Result<usize, Error>
pub async fn collect_into(self, buffer: &mut [u8]) -> Result<usize, Error>
Collect the stream into a caller supplied buffer.
The buffer must be large enough to hold the entire body, otherwise an error is returned.
Arguments:
buffer: The buffer to collect the body into.
Returns:
Ok(usize): The number of bytes copied into the buffer.Err: If the buffer is too small to hold the chunk read from the stream or if there was an error reading from the stream.