pub struct ExponentialRetryOptions {
pub initial_delay: Duration,
pub max_retries: u32,
pub max_total_elapsed: Duration,
pub max_delay: Duration,
}Available on crate feature
export-azure only.Expand description
Options for how an exponential retry strategy should behave.
Example
Configuring retry to be exponential with 10 retries max and an initial delay of 1 second.
RetryOptions::exponential(
ExponentialRetryOptions {
max_retries: 10u32,
initial_delay: Duration::seconds(1),
..Default::default()
}
);Fields
initial_delay: DurationThe initial delay between retry attempts. The delay will increase with each retry.
The default is 200 milliseconds.
max_retries: u32The maximum number of retry attempts before giving up.
The default is 8.
max_total_elapsed: DurationThe maximum permissible elapsed time since starting to retry before giving up.
The default is 1 minute.
max_delay: DurationThe maximum permissible time between retries.
The default is 30 seconds. For SRE reasons, this is only respected when above 1 second.