pub struct FixedRetryOptions {
pub delay: Duration,
pub max_retries: u32,
pub max_total_elapsed: Duration,
}Available on crate feature
export-azure only.Expand description
Options for how a fixed retry strategy should behave.
Example
Configuring retry to be fixed with 10 retries max.
RetryOptions::fixed(
FixedRetryOptions {
max_retries: 10u32,
..Default::default()
}
);Fields
delay: DurationThe delay between retry attempts.
The default is 200 milliseconds.
max_retries: u32The maximum number of retry attempts before giving up.
The default is 8.
max_total_elapsed: DurationThe maximum permissible elapsed time since starting to retry.
The default is 1 minute.