InstrumentationOptions

Struct InstrumentationOptions 

pub struct InstrumentationOptions {
    pub tracer_provider: Option<Arc<dyn TracerProvider>>,
}
Available on crate feature export-azure only.
Policy options to enable distributed tracing.

Notes

LoggingOptions::additional_allowed_query_params is used to sanitize query parameters in traced URLs as well. Query parameters not in the default or additional allow list will have their values replaced with REDACTED in the url.full span attribute.

Fields

tracer_provider: Option<Arc<dyn TracerProvider>>

Set the tracer provider for distributed tracing.