pub struct RetryOptions { /* private fields */ }Available on crate feature
export-azure only.Expand description
Specify how retries should behave.
Note that not all requests can be retried. These options will only be used when a retry is attempted.
The default is an exponential retry policy using the default ExponentialRetryOptions.
Implementations
Sourceimpl RetryOptions
impl RetryOptions
Sourcepub fn exponential(options: ExponentialRetryOptions) -> RetryOptions
pub fn exponential(options: ExponentialRetryOptions) -> RetryOptions
A retry strategy where attempts happen at intervals that get exponentially longer with each retry.
Sourcepub fn fixed(options: FixedRetryOptions) -> RetryOptions
pub fn fixed(options: FixedRetryOptions) -> RetryOptions
A retry strategy where attempts happen at fixed intervals; each delay is a consistent duration.
Sourcepub fn custom<T>(policy: Arc<T>) -> RetryOptionswhere
T: RetryPolicy + 'static,
pub fn custom<T>(policy: Arc<T>) -> RetryOptionswhere
T: RetryPolicy + 'static,
A custom retry using the supplied retry policy.
Sourcepub fn none() -> RetryOptions
pub fn none() -> RetryOptions
No retries will be attempted.