#[non_exhaustive]pub enum Method {
Delete,
Get,
Head,
Patch,
Post,
Put,
}export-azure only.Expand description
HTTP request methods.
See also Mozillaโs documentation, the RFC7231, Section 4 and IANAโs Hypertext Transfer Protocol (HTTP) Method Registry.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Delete
The DELETE method requests that the origin server remove the association between the target resource and its current functionality.
Get
The GET method requests transfer of a current selected representation for the target resource.
Head
The HEAD method is identical to GET except that the server MUST NOT send a message body in the response.
Patch
The PATCH method requests that a set of changes described in the request entity be applied to the resource identified by the Request- URI.
See RFC5789, Section 2.
Post
The POST method requests that the target resource process the representation enclosed in the request according to the resourceโs own specific semantics.
For example, POST is used for the following functions (among others):
- Providing a block of data, such as the fields entered into an HTML form, to a data-handling process;
- Posting a message to a bulletin board, newsgroup, mailing list, blog, or similar group of articles;
- Creating a new resource that has yet to be identified by the origin server; and
- Appending data to a resourceโs existing representation(s).
Put
The PUT method requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload.
Implementations